<?php

/**
 * @file
 * Helper functions for the Important Information block.
 *
 * Use module_load_include('inc', 'important_information',
 * 'important_information.block')
 * to use these functions within another module.
 *
 * This is automatically loaded onto the module to span
 * the pages related to the new block configuration.
 *
 * @ingroup important_information
 */

/**
 * Implements hook_block_info().
 */
function important_information_block_info() {
  $blocks['important_information'] = array(
    // The name that will appear in the block list.
    'info' => t('Important information'),
    // Default setting.
    'cache' => DRUPAL_CACHE_PER_ROLE,
  );
  return $blocks;
}

/**
 * Implements hook_block_view().
 */
function important_information_block_view($delta = '') {
  $block = array();
  switch ($delta) {
    case 'important_information':
      module_load_include('inc', 'important_information', 'important_information');
      $cssPath = (module_exists('sassy')) ? '/scss/main.scss' : '/css/main.css';
      $availableThemes = json_decode(variable_get('important_information__themes', "[]"), TRUE);
      $currentTheme = variable_get('important_information__theme', "default");
      $settings = json_decode($availableThemes[$currentTheme], TRUE);
      $custom_css = _important_information_css($settings);
      drupal_add_js(array(
        'important_information' => array(
          'enable_dismiss' => $settings['enable_dismiss'],
          'enable_full_screen' => $settings['enable_full_screen'],
          'full_screen_title_override' => $settings['al_fs_topbar_override'],
        ),
      ), 'setting');
      $module_path = drupal_get_path('module', 'important_information');
      $block['content']['#markup'] = theme('important_information', $settings);
      $block['content']['#attached'] = array(
        'css' => array(
          $module_path . $cssPath,
          array(
            'scope' => 'footer',
            'data' => $custom_css,
            'type' => 'inline',
          ),
        ),
        'js' => array(
          $module_path . '/js/main.js',
        ),
      );
      break;

  }
  return $block;
}

/**
 * Implements hook_block_save().
 */
function important_information_block_save($delta = '', $edit = array()) {
  if ($delta == 'important_information') {
    if (!user_access('administer important information')) {
      drupal_access_denied();
      drupal_exit();
      return;
    }
    // Set selected theme.
    if ($edit['new_theme'] != "") {
      $theme = $edit['new_theme'];
    }
    else {
      $theme = $edit['theme'];
    }
    // Fix size value.
    if (strpos($edit['size'], '%') !== FALSE
    || strpos($edit['size'], 'vw') !== FALSE
    || strpos($edit['size'], 'vh') !== FALSE) {
      switch ($edit['position']) {
        case 'top':
        case 'bottom':
          $edit['size'] = str_replace('%', 'vh', $edit['size']);
          $edit['size'] = str_replace('vw', 'vh', $edit['size']);
          break;

        case 'left':
        case 'right':
          $edit['size'] = str_replace('%', 'vw', $edit['size']);
          $edit['size'] = str_replace('vh', 'vw', $edit['size']);
          break;

      }
    }
    if (strpos($edit['mobile_size'], '%') !== FALSE
    || strpos($edit['mobile_size'], 'vw') !== FALSE
    || strpos($edit['mobile_size'], 'vh') !== FALSE) {
      switch ($edit['mobile_position']) {
        case 'top':
        case 'bottom':
          $edit['mobile_size'] = str_replace('%', 'vh', $edit['mobile_size']);
          $edit['mobile_size'] = str_replace('vw', 'vh', $edit['mobile_size']);
          break;

        case 'left':
        case 'right':
          $edit['mobile_size'] = str_replace('%', 'vw', $edit['mobile_size']);
          $edit['mobile_size'] = str_replace('vh', 'vw', $edit['mobile_size']);
          break;

      }
    }
    global $user;
    $files = array();
    if ($edit['al_d_icon'] != "") {
      // Load the file via file.fid.
      $files[] = file_load($edit['al_d_icon']);
    }
    if ($edit['al_d_icon_back'] != "") {
      // Load the file via file.fid.
      $files[] = file_load($edit['al_d_icon_back']);
    }
    if ($edit['al_fs_icon'] != "") {
      // Load the file via file.fid.
      $files[] = file_load($edit['al_fs_icon']);
    }
    if ($edit['al_fs_icon_back'] != "") {
      // Load the file via file.fid.
      $files[] = file_load($edit['al_fs_icon_back']);
    }
    foreach ($files as $file) {
      // Change status to permanent.
      $file->status = FILE_STATUS_PERMANENT;
      // Save.
      file_save($file);
      // Record that the module is using the file.
      file_usage_add($file, 'important_information', 'important_information_full_screen_back', $user->uid);
    }
    _important_information_settings_theme($theme, $edit);
  }
}

/**
 * Implements hook_block_configure().
 */
function important_information_block_configure($delta = '') {
  $form = array();
  if ($delta == 'important_information') {
    if (!user_access('administer important information')) {
      drupal_access_denied();
      drupal_exit();
      return;
    }
    module_load_include('inc', 'important_information', 'important_information');
    $availableThemes = json_decode(variable_get('important_information__themes', "[]"), TRUE);
    $availableThemeKeys = array_keys($availableThemes);
    $availableKeys = [];
    foreach ($availableThemeKeys as $availableTheme) {
      $availableKeys[$availableTheme] = $availableTheme;
    }
    if (count($availableKeys) == 0) {
      $availableKeys[] = "default";
    }
    $currentTheme = variable_get('important_information__theme', "default");
    $settings = json_decode($availableThemes[$currentTheme], TRUE);
    drupal_add_js(array(
      'important_information' => array(
        'themes' => $availableThemes,
      ),
    ), 'setting');
    drupal_add_js(drupal_get_path('module', 'important_information') . '/js/block-form.js');
    $form['general'] = array(
      '#type' => 'fieldset',
      '#title' => t('General'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['general']['display']['top_bar'] = array(
      '#type' => 'fieldset',
      '#title' => t('Top bar'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['general']['display']['top_bar']['margin'] = array(
      '#type' => 'fieldset',
      '#title' => t('Margin'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['general']['display']['top_bar']['margin']['tb_margin_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['tb_margin_top'],
      '#description' => t('The top margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['margin']['tb_margin_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['tb_margin_right'],
      '#description' => t('The right margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['margin']['tb_margin_bottom'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['tb_margin_bottom'],
      '#description' => t('The bottom margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['margin']['tb_margin_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['tb_margin_left'],
      '#description' => t('The left margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['padding'] = array(
      '#type' => 'fieldset',
      '#title' => t('Padding'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['general']['display']['top_bar']['padding']['tb_padding_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['tb_padding_top'],
      '#description' => t('The top padding applied to the top bar.<br>Default: 10px.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['padding']['tb_padding_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['tb_padding_right'],
      '#description' => t('The right padding applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['padding']['tb_padding_bottom'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['tb_padding_bottom'],
      '#description' => t('The bottom padding applied to the top bar.<br>Default: 10px.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['padding']['tb_padding_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['tb_padding_left'],
      '#description' => t('The left padding applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_title'] = array(
      '#type' => 'textfield',
      '#title' => t('Title'),
      '#default_value' => $settings['tb_title'],
      '#description' => t('The text which appears at the top bar of the section.<br>Leave empty for no top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#default_value' => $settings['tb_height'],
      '#description' => t('The height of the bar where the text will appear.<br>Default: 40px.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['tb_width'],
      '#description' => t('The width of the bar where the text will appear.<br>Default: 100%.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_max_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Max width'),
      '#default_value' => $settings['tb_max_width'],
      '#description' => t('The max width of the bar where the text will appear.<br>Default: 100%.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_text_indent'] = array(
      '#type' => 'textfield',
      '#title' => t('Text indent'),
      '#default_value' => $settings['tb_text_indent'],
      '#description' => t('The spacing applied to the text from the corner of the top bar.<br>Default: 10px.'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_font_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Font color'),
      '#default_value' => $settings['tb_font_color'],
      '#description' => t('The color applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['tb_font_weight'],
      '#description' => t('The weight applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_font_family'] = array(
      '#type' => 'textfield',
      '#title' => t('Font family'),
      '#default_value' => $settings['tb_font_family'],
      '#description' => t('The family applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['tb_font_size'],
      '#description' => t('The size applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_background_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Background color'),
      '#default_value' => $settings['tb_background_color'],
      '#description' => t('The background color applied to the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['top_bar']['tb_position'] = array(
      '#type' => 'select',
      '#title' => t('Position'),
      '#options' => array(
        'absolute' => t('Absolute'),
        'fixed' => t('Fixed'),
        'relative' => t('Relative'),
        'block' => t('Block'),
        'table' => t('Table'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['tb_position'],
      '#description' => t('The position type applied to the bar.<br>Default: Absolute.'),
    );
    $form['general']['display']['top_bar']['tb_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['tb_text_transform'],
      '#description' => t('The transform applied to the text on the top bar.<br>Default: Unset.'),
    );
    $form['general']['display']['top_bar']['tb_text_align'] = array(
      '#type' => 'select',
      '#title' => t('Text align'),
      '#options' => array(
        'center' => t('Center'),
        'left' => t('Left'),
        'right' => t('Right'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['tb_text_align'],
      '#description' => t('The alignment applied to the text bar.<br>Default: Left.'),
    );
    $form['general']['display']['sub_bar'] = array(
      '#type' => 'fieldset',
      '#title' => t('Sub bar'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['general']['display']['sub_bar']['margin'] = array(
      '#type' => 'fieldset',
      '#title' => t('Margin'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['general']['display']['sub_bar']['margin']['sb_margin_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['sb_margin_top'],
      '#description' => t('The top margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['margin']['sb_margin_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['sb_margin_right'],
      '#description' => t('The right margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['margin']['sb_margin_bottom'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['sb_margin_bottom'],
      '#description' => t('The bottom margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['margin']['sb_margin_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['sb_margin_left'],
      '#description' => t('The left margin applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['padding'] = array(
      '#type' => 'fieldset',
      '#title' => t('Padding'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['general']['display']['sub_bar']['padding']['sb_padding_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['sb_padding_top'],
      '#description' => t('The top padding applied to the top bar.<br>Default: 10px.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['padding']['sb_padding_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['sb_padding_right'],
      '#description' => t('The right padding applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['padding']['sb_padding_bottom'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['sb_padding_bottom'],
      '#description' => t('The bottom padding applied to the top bar.<br>Default: 10px.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['padding']['sb_padding_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['sb_padding_left'],
      '#description' => t('The left padding applied to the top bar.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_title'] = array(
      '#type' => 'textfield',
      '#title' => t('Title'),
      '#default_value' => $settings['sb_title'],
      '#description' => t('The text which appears at the top bar of the section.<br>Leave empty for no top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#default_value' => $settings['sb_height'],
      '#description' => t('The height of the bar where the text will appear.<br>Default: 40px.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['sb_width'],
      '#description' => t('The width of the bar where the text will appear.<br>Default: 100%.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_max_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Max width'),
      '#default_value' => $settings['sb_max_width'],
      '#description' => t('The max width of the bar where the text will appear.<br>Default: 100%.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_text_indent'] = array(
      '#type' => 'textfield',
      '#title' => t('Text indent'),
      '#default_value' => $settings['sb_text_indent'],
      '#description' => t('The spacing applied to the text from the corner of the top bar.<br>Default: 10px.'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_font_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Font color'),
      '#default_value' => $settings['sb_font_color'],
      '#description' => t('The color applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['sb_font_weight'],
      '#description' => t('The weight applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_font_family'] = array(
      '#type' => 'textfield',
      '#title' => t('Font family'),
      '#default_value' => $settings['sb_font_family'],
      '#description' => t('The family applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['sb_font_size'],
      '#description' => t('The size applied to the font on the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_background_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Background color'),
      '#default_value' => $settings['sb_background_color'],
      '#description' => t('The background color applied to the top bar.<br>Default: (none).'),
      '#size' => 60,
    );
    $form['general']['display']['sub_bar']['sb_position'] = array(
      '#type' => 'select',
      '#title' => t('Position'),
      '#options' => array(
        'absolute' => t('Absolute'),
        'fixed' => t('Fixed'),
        'relative' => t('Relative'),
        'block' => t('Block'),
        'table' => t('Table'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['sb_position'],
      '#description' => t('The position type applied to the bar.<br>Default: Absolute.'),
    );
    $form['general']['display']['sub_bar']['sb_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['sb_text_transform'],
      '#description' => t('The transform applied to the text on the top bar.<br>Default: Unset.'),
    );
    $form['general']['display']['sub_bar']['sb_text_align'] = array(
      '#type' => 'select',
      '#title' => t('Text align'),
      '#options' => array(
        'center' => t('Center'),
        'left' => t('Left'),
        'right' => t('Right'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['sb_text_align'],
      '#description' => t('The alignment applied to the text bar.<br>Default: Left.'),
    );
    $form['general']['theme'] = array(
      '#type' => 'select',
      '#title' => t('Theme'),
      '#options' => $availableKeys,
      '#default_value' => $currentTheme,
      '#required' => TRUE,
      '#description' => t('The preset of settings to use.<br>Default: default.'),
    );
    $form['general']['new_theme'] = array(
      '#type' => 'textfield',
      '#title' => t('New theme name'),
      '#default_value' => "",
      '#description' => t('Enter the name for saving a new set of settings as a theme.<br>All the settings will be saved, and a new option will appear on the select above.<br>Default: empty.'),
      '#size' => 60,
    );
    $form['general']['body'] = array(
      '#type' => 'text_format',
      '#title' => t('Body'),
      '#description' => t('Enter important information to be displayed here.'),
      '#default_value' => $settings['body']['value'],
      '#format' => $settings['body']['format'],
      '#size' => 60,
      '#required' => TRUE,
    );
    $form['action_links'] = array(
      '#type' => 'fieldset',
      '#title' => t('Action links'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['action_links']['al_position'] = array(
      '#type' => 'select',
      '#title' => t('Position'),
      '#options' => array(
        'fixed' => t('Fixed'),
        'absolute' => t('Absolute'),
        'hidden' => t('Hidden'),
        '' => t('None'),
      ),
      '#default_value' => $settings['al_position'],
      '#description' => t('Set the position of the action links for the user.<br>Use Fixed to define the position with the placement configurations below.<br>Use Hidden to apply a hidden style to the elements.<br>Set it to None to define that yourself via custom CSS.<br>Default: None.'),
    );
    $form['action_links']['al_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top spacing'),
      '#default_value' => $settings['al_top'],
      '#description' => t('Enter the amount of spacing which is applied on the top for the action links.<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['al_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left spacing'),
      '#default_value' => $settings['al_left'],
      '#description' => t('Enter the amount of spacing which is applied on the left for the action links.<br>Only use left or right, not both.<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['al_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right spacing'),
      '#default_value' => $settings['al_right'],
      '#description' => t('Enter the amount of spacing which is applied on the right for the action links.<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss'] = array(
      '#type' => 'fieldset',
      '#title' => t('Dismiss button'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['action_links']['dismiss']['enable_dismiss'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable button'),
      '#default_value' => $settings['enable_dismiss'],
      '#description' => t('Enable a button to dismiss the block for the current page.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text'),
      '#default_value' => $settings['al_d_text'],
      '#description' => t('Enter the text which should be applied to the button.<br>Default: x.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['al_d_width'],
      '#description' => t('Enter the width which should be applied to the button.<br>Default: 15px.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#default_value' => $settings['al_d_height'],
      '#description' => t('Enter the height which should be applied to the button.<br>Default: 15px.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_class'] = array(
      '#type' => 'textfield',
      '#title' => t('Font-awesome class'),
      '#default_value' => $settings['al_d_class'],
      '#description' => t('Enter the font-awesome class which should be used to load the icon for this button.<br>The font-awesome library should be loaded onto the site already, since the module does not load it for you.<br>Leave empty to use an image instead (defined below).<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_class_back'] = array(
      '#type' => 'textfield',
      '#title' => t('Font-awesome class (back)'),
      '#default_value' => $settings['al_d_class_back'],
      '#description' => t('Enter the font-awesome class which should be used to load the icon for this button when the button has been activated.<br>The font-awesome library should be loaded onto the site already, since the module does not load it for you.<br>Leave empty to use an image instead (defined below).<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_use_icons'] = array(
      '#type' => 'checkbox',
      '#title' => t('Use icons'),
      '#default_value' => $settings['al_d_use_icons'],
      '#description' => t('Use the images uploaded below as the button icons.<br>Default: disabled.'),
      '#size' => 60,
    );
    $icon_file = file_load($settings['al_d_icon']);
    $icon_thumb = "";
    if ($icon_file) {
      $icon_url = file_create_url($icon_file->uri);
      $icon_thumb = "Current: <img src='{$icon_url}' style='width: 25px;height: 25px;'\><br>";
    }
    $form['action_links']['dismiss']['al_d_icon'] = array(
      '#type' => 'managed_file',
      '#title' => t('Icon'),
      '#description' => "Upload an image to use as the icon for this button.<br>{$icon_thumb}Default: empty.",
      '#size' => 60,
      '#upload_location' => 'public://important_information/',
    );
    $icon_file = file_load($settings['al_fs_icon_back']);
    $icon_thumb = "";
    if ($icon_file) {
      $icon_url = file_create_url($icon_file->uri);
      $icon_thumb = "Current: <img src='{$icon_url}' style='width: 25px;height: 25px;'\><br>Please refresh the page if you have changed from one theme to another if you want to see the icon from another theme.<br>";
    }
    $form['action_links']['dismiss']['al_d_icon_back'] = array(
      '#type' => 'managed_file',
      '#title' => t('Icon (back)'),
      '#description' => "Upload an image to use as the icon for this button when the button has been activated.<br>{$icon_thumb}Default: empty.",
      '#size' => 60,
      '#upload_location' => 'public://important_information/',
    );
    $form['action_links']['dismiss']['al_d_icon_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Icon size'),
      '#default_value' => $settings['al_d_icon_size'],
      '#description' => t('Enter the size for the icon which appears within the button.<br>Default: cover.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_background_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Background color'),
      '#default_value' => $settings['al_d_background_color'],
      '#description' => t('Enter the background color which should be applied to the button.<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_icon_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Icon color'),
      '#default_value' => $settings['al_d_icon_color'],
      '#description' => t('Enter the color which should be applied to the icon (in the case that it is a Font-Awesome icon).<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['al_d_line_height'],
      '#description' => t('Enter the line height to vertically center the icon within the button.<br>Default: 15px.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_text_align'] = array(
      '#type' => 'select',
      '#title' => t('Alignment'),
      '#options' => array(
        'center' => t('Center'),
        'left' => t('Left'),
        'right' => t('Right'),
        '' => t('None'),
      ),
      '#default_value' => $settings['al_d_text_align'],
      '#description' => t('Set the alignment for the icon within the button.<br>Default: Center.'),
    );
    $form['action_links']['dismiss']['al_d_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['al_d_padding'],
      '#description' => t('Enter the amount of padding to set for the button.<br>You can enter multiple values separated by a space in order to set side-specific values.<br>Default: 5px.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['al_d_font_weight'],
      '#description' => t('Enter a font-weight value for the icon to look bolder or softer (if using text).<br>Default: 600.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_font_family'] = array(
      '#type' => 'textfield',
      '#title' => t('Font family'),
      '#default_value' => $settings['al_d_font_family'],
      '#description' => t('Enter the font class to use for loading the icon.<br>Default: Font Awesome\ 5 Free.'),
      '#size' => 60,
    );
    $form['action_links']['dismiss']['al_d_float'] = array(
      '#type' => 'select',
      '#title' => t('Alignment'),
      '#options' => array(
        'left' => t('Left'),
        'right' => t('Right'),
        '' => t('None'),
      ),
      '#default_value' => $settings['al_d_float'],
      '#description' => t('Set the float property of the button.<br>Default: right.'),
    );
    $form['action_links']['dismiss']['al_d_z_index'] = array(
      '#type' => 'textfield',
      '#title' => t('Z-index'),
      '#default_value' => $settings['al_d_z_index'],
      '#description' => t('Enter the z-index used for this button.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen'] = array(
      '#type' => 'fieldset',
      '#title' => t('Full screen button'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['action_links']['full_screen']['enable_full_screen'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable button'),
      '#default_value' => $settings['enable_full_screen'],
      '#description' => t('Enable a button to expand the block to cover all the page.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_topbar_override'] = array(
      '#type' => 'textfield',
      '#title' => t('Top bar title'),
      '#default_value' => $settings['al_fs_topbar_override'],
      '#description' => t('Enter the title which should appear on top of the section after you clicked on the button.<br>If the title says `Show more Important Information`, then you can put here: `Show less Important Information`.<br>Leave empty for no override, or type (empty) for no topbar when on full screen mode.</br><br>Default: (empty).'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text'),
      '#default_value' => $settings['al_fs_text'],
      '#description' => t('Enter the text which should be applied to the button.<br>Default: &#9650;.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_text_open'] = array(
      '#type' => 'textfield',
      '#title' => t('Text (open)'),
      '#default_value' => $settings['al_fs_text_open'],
      '#description' => t('Enter the text which should be applied to the button when the mode is full screen.<br>Default: &#9660;.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['al_fs_width'],
      '#description' => t('Enter the width which should be applied to the button.<br>Default: 15px.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#default_value' => $settings['al_fs_height'],
      '#description' => t('Enter the height which should be applied to the button.<br>Default: 15px.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_class'] = array(
      '#type' => 'textfield',
      '#title' => t('Font-awesome class'),
      '#default_value' => $settings['al_fs_class'],
      '#description' => t('Enter the font-awesome class which should be used to load the icon for this button.<br>The font-awesome library should be loaded onto the site already, since the module does not load it for you.<br>Leave empty to use an image instead (defined below).<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_class_back'] = array(
      '#type' => 'textfield',
      '#title' => t('Font-awesome class (back)'),
      '#default_value' => $settings['al_fs_class_back'],
      '#description' => t('Enter the font-awesome class which should be used to load the icon for this button after the button has been activated.<br>The font-awesome library should be loaded onto the site already, since the module does not load it for you.<br>Leave empty to use an image instead (defined below).<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_use_icons'] = array(
      '#type' => 'checkbox',
      '#title' => t('Use icons'),
      '#default_value' => $settings['al_fs_use_icons'],
      '#description' => t('Use the images uploaded below as the button icons.<br>Default: disabled.'),
      '#size' => 60,
    );
    $icon_file = file_load($settings['al_fs_icon']);
    $icon_thumb = "";
    if ($icon_file) {
      $icon_url = file_create_url($icon_file->uri);
      $icon_thumb = "Current: <img src='{$icon_url}' style='width: 25px;height: 25px;'\><br>Please refresh the page if you have changed from one theme to another if you want to see the icon from another theme.<br>";
    }
    $form['action_links']['full_screen']['al_fs_icon'] = array(
      '#type' => 'managed_file',
      '#title' => t('Icon'),
      '#description' => "Upload an image to use as the icon for this button.<br>{$icon_thumb}Default: empty.",
      '#size' => 60,
      '#upload_location' => 'public://important_information/',
    );
    $icon_file = file_load($settings['al_fs_icon_back']);
    $icon_thumb = "";
    if ($icon_file) {
      $icon_url = file_create_url($icon_file->uri);
      $icon_thumb = "Current: <img src='{$icon_url}' style='width: 25px;height: 25px;'\><br>Please refresh the page if you have changed from one theme to another if you want to see the icon from another theme.<br>";
    }
    $form['action_links']['full_screen']['al_fs_icon_back'] = array(
      '#type' => 'managed_file',
      '#title' => t('Icon (back)'),
      '#description' => "Upload an image to use as the icon for this button to use when the button has been activated.<br>{$icon_thumb}Default: empty.",
      '#size' => 60,
      '#upload_location' => 'public://important_information/',
    );
    $form['action_links']['full_screen']['al_fs_icon_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Icon size'),
      '#default_value' => $settings['al_fs_icon_size'],
      '#description' => t('Enter the size for the icon which appears within the button.<br>Default: cover.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_background_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Background color'),
      '#default_value' => $settings['al_fs_background_color'],
      '#description' => t('Enter the background color which should be applied to the button.<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_icon_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Icon color'),
      '#default_value' => $settings['al_fs_icon_color'],
      '#description' => t('Enter the color which should be applied to the icon (in the case that it is a Font-Awesome icon).<br>Default: empty.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['al_fs_line_height'],
      '#description' => t('Enter the line height to vertically center the icon within the button.<br>Default: 15px.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_text_align'] = array(
      '#type' => 'select',
      '#title' => t('Alignment'),
      '#options' => array(
        'center' => t('Center'),
        'left' => t('Left'),
        'right' => t('Right'),
        '' => t('None'),
      ),
      '#default_value' => $settings['al_fs_text_align'],
      '#description' => t('Set the alignment for the icon within the button.<br>Default: Center.'),
    );
    $form['action_links']['full_screen']['al_fs_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['al_fs_padding'],
      '#description' => t('Enter the amount of padding to set for the button.<br>You can enter multiple values separated by a space in order to set side-specific values.<br>Default: 5px.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['al_fs_font_weight'],
      '#description' => t('Enter a font-weight value for the icon to look bolder or softer (if using text).<br>Default: 600.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_font_family'] = array(
      '#type' => 'textfield',
      '#title' => t('Font family'),
      '#default_value' => $settings['al_fs_font_family'],
      '#description' => t('Enter the font class to use for loading the icon.<br>Default: Font Awesome\ 5 Free.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['al_fs_float'] = array(
      '#type' => 'select',
      '#title' => t('Alignment'),
      '#options' => array(
        'left' => t('Left'),
        'right' => t('Right'),
        '' => t('None'),
      ),
      '#default_value' => $settings['al_fs_float'],
      '#description' => t('Set the float property of the button.<br>Default: right.'),
    );
    $form['action_links']['full_screen']['al_fs_z_index'] = array(
      '#type' => 'textfield',
      '#title' => t('Z-index'),
      '#default_value' => $settings['al_fs_z_index'],
      '#description' => t('Enter the z-index used for this button.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['window'] = array(
      '#type' => 'fieldset',
      '#title' => t('Window'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['action_links']['full_screen']['window']['al_fs_w_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['al_fs_w_padding'],
      '#description' => t('The padding applied to the full screen window which opens when the full screen is activated.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['window']['al_fs_w_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['al_fs_w_width'],
      '#description' => t('The width applied to the full screen window which opens when the full screen is activated.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['window']['al_fs_w_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#default_value' => $settings['al_fs_w_height'],
      '#description' => t('The height applied to the full screen window which opens when the full screen is activated.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['window']['al_fs_w_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['al_fs_w_top'],
      '#description' => t('The top spacing applied to the full screen window which opens when the full screen is activated.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['action_links']['full_screen']['window']['al_fs_w_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['al_fs_w_left'],
      '#description' => t('The left spacing applied to the full screen window which opens when the full screen is activated.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style'] = array(
      '#type' => 'fieldset',
      '#title' => t('Style'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['display'] = array(
      '#type' => 'fieldset',
      '#title' => t('Display'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['display']['position'] = array(
      '#type' => 'select',
      '#title' => t('Position'),
      '#options' => array(
        'top' => t('Top'),
        'right' => t('Right'),
        'bottom' => t('Bottom'),
        'left' => t('Left'),
        'hidden' => t('Hidden'),
      ),
      '#default_value' => $settings['position'],
      '#description' => t('Set the position of the information for the user.<br>Default: Right.'),
    );
    $form['style']['display']['size'] = array(
      '#type' => 'textfield',
      '#title' => t('Section size'),
      '#default_value' => $settings['size'],
      '#description' => t('The amount of pixels the section should cover.<br>If it is a bottom or top, then this value corresponds to the height.<br>The following units are allowed: px, vw, vh.<br>% gets converted to vh or vw depending on the position.<br>Default: 300px.'),
      '#size' => 60,
    );
    $form['style']['display']['mobile_position'] = array(
      '#type' => 'select',
      '#title' => t('Mobile position'),
      '#options' => array(
        'top' => t('Top'),
        'right' => t('Right'),
        'bottom' => t('Bottom'),
        'left' => t('Left'),
        'hidden' => t('Hidden'),
      ),
      '#default_value' => $settings['mobile_position'],
      '#description' => t('Set the position of the information for the user in mobile devices.<br>Default: Top.'),
    );
    $form['style']['display']['mobile_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Mobile section size'),
      '#default_value' => $settings['mobile_size'],
      '#description' => t('The amount of pixels the section should cover in mobile devices.<br>If it is a bottom or top, then this value corresponds to the height.<br>The following units are allowed: px, vw, vh.<br>% gets converted to vh or vw depending on the position.<br>Default: 300px.'),
      '#size' => 60,
    );
    $form['style']['display']['mobile_breakpoint'] = array(
      '#type' => 'textfield',
      '#title' => t('Mobile breakpoint'),
      '#default_value' => $settings['mobile_breakpoint'],
      '#description' => t('The screen width which separates the desktop display from the mobile.<br>Leave empty to disable mobile styles.<br>Default: 768px.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing'] = array(
      '#type' => 'fieldset',
      '#title' => t('Inner Spacing: Desktop'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['display']['inner_spacing']['insp_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['insp_top'],
      '#description' => t('The amount of pixels the content should be apart from the border on the top.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing']['insp_bottom'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['insp_bottom'],
      '#description' => t('The amount of pixels the content should be apart from the border on the bottom.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing']['insp_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['insp_left'],
      '#description' => t('The amount of pixels the content should be apart from the border on the left.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing']['insp_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['insp_right'],
      '#description' => t('The amount of pixels the content should be apart from the border on the right.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing'] = array(
      '#type' => 'fieldset',
      '#title' => t('Outer Spacing: Desktop'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['display']['outer_spacing']['ousp_top'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['ousp_top'],
      '#description' => t('The amount of pixels the block should be apart from the page to the top.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing']['ousp_bottom'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['ousp_bottom'],
      '#description' => t('The amount of pixels the block should be apart from the page to the bottom.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing']['ousp_left'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['ousp_left'],
      '#description' => t('The amount of pixels the block should be apart from the page to the left.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing']['ousp_right'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['ousp_right'],
      '#description' => t('The amount of pixels the block should be apart from the page to the right.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing_m'] = array(
      '#type' => 'fieldset',
      '#title' => t('Inner Spacing: Mobile'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['display']['inner_spacing_m']['insp_top_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['insp_top_m'],
      '#description' => t('The amount of pixels the content should be apart from the border on the top.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing_m']['insp_bottom_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['insp_bottom_m'],
      '#description' => t('The amount of pixels the content should be apart from the border on the bottom.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing_m']['insp_left_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['insp_left_m'],
      '#description' => t('The amount of pixels the content should be apart from the border on the left.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['inner_spacing_m']['insp_right_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['insp_right_m'],
      '#description' => t('The amount of pixels the content should be apart from the border on the right.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 10.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing_m'] = array(
      '#type' => 'fieldset',
      '#title' => t('Outer Spacing: Mobile'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['display']['outer_spacing_m']['ousp_top_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Top'),
      '#default_value' => $settings['ousp_top_m'],
      '#description' => t('The amount of pixels the block should be apart from the page to the top.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing_m']['ousp_bottom_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Bottom'),
      '#default_value' => $settings['ousp_bottom_m'],
      '#description' => t('The amount of pixels the block should be apart from the page to the bottom.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing_m']['ousp_left_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Left'),
      '#default_value' => $settings['ousp_left_m'],
      '#description' => t('The amount of pixels the block should be apart from the page to the left.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['outer_spacing_m']['ousp_right_m'] = array(
      '#type' => 'textfield',
      '#title' => t('Right'),
      '#default_value' => $settings['ousp_right_m'],
      '#description' => t('The amount of pixels the block should be apart from the page to the right.<br>The unit is automatically set as <em>px</em>, so use numbers only.<br>Default: 0.'),
      '#size' => 60,
    );
    $form['style']['display']['body_spacing_type'] = array(
      '#type' => 'select',
      '#title' => t('Body spacing type'),
      '#options' => array(
        'margin' => t('Margin'),
        'padding' => t('Padding'),
        'none' => t('None'),
      ),
      '#default_value' => $settings['body_spacing_type'],
      '#description' => t('The type of spacing applied to the body for placing the block.<br>Use `None` if you wish to control the spacing with your own theme CSS.<br>Default: margin.'),
    );
    $form['style']['color'] = array(
      '#type' => 'fieldset',
      '#title' => t('Color'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['color']['top_background_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Top: Background color'),
      '#default_value' => $settings['top_background_color'],
      '#description' => t('The background color applied to the top of the block where the title lives.<br>Default: white.'),
      '#size' => 60,
    );
    $form['style']['color']['body_background_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Body: Background color'),
      '#default_value' => $settings['body_background_color'],
      '#description' => t('The background color applied to the body of the block where the copy lives.<br>Default: white.'),
      '#size' => 60,
    );
    $form['style']['border'] = array(
      '#type' => 'fieldset',
      '#title' => t('Border'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['border']['border_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Color'),
      '#default_value' => $settings['border_color'],
      '#description' => t('The CSS color applied to the border of the block.<br>Default: #ccc.'),
      '#size' => 60,
    );
    $form['style']['border']['border_style'] = array(
      '#type' => 'select',
      '#title' => t('Style'),
      '#options' => array(
        'none' => t('None'),
        'hidden' => t('Hidden'),
        'dotted' => t('Dotted'),
        'dashed' => t('Dashed'),
        'solid' => t('Solid'),
        'double' => t('Double'),
        'groove' => t('Groove'),
        'ridge' => t('Ridge'),
        'inset' => t('Inset'),
        'outset' => t('Outset'),
        'initial' => t('Initial'),
        'inherit' => t('Inherit'),
      ),
      '#default_value' => $settings['border_style'],
      '#description' => t('The type of border applied to the block.<br>Default: solid.'),
    );
    $form['style']['border']['border_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['border_width'],
      '#description' => t('The amount of pixels for the width of the border line.<br>The unit of measurement is always <em>px</em>, so use numbers only.<br>Default: 1.'),
      '#size' => 60,
    );
    $form['style']['border']['border_override'] = array(
      '#type' => 'textfield',
      '#title' => t('Border override'),
      '#default_value' => $settings['border_override'],
      '#description' => t('Enter the literal border style which should be assigned to the border property.<br>Example: <b>border-top: 2px solid #003e73;</b><br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['shadow'] = array(
      '#type' => 'fieldset',
      '#title' => t('Shadow'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['shadow']['shadow_h_offset'] = array(
      '#type' => 'textfield',
      '#title' => t('Horizontal offset'),
      '#default_value' => $settings['shadow_h_offset'],
      '#description' => t('The horizontal offset applied to the shadow.<br>Property highlighted in example: <b>10px</b> 10px 8px 10px #888888<br>Please enter a value for all the fields to toggle the shadow properties.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['shadow']['shadow_v_offset'] = array(
      '#type' => 'textfield',
      '#title' => t('Vertical offset'),
      '#default_value' => $settings['shadow_v_offset'],
      '#description' => t('The vertical offset applied to the shadow.<br>Property highlighted in example: 10px <b>10px</b> 8px 10px #888888<br>Please enter a value for all the fields to toggle the shadow properties.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['shadow']['shadow_blur'] = array(
      '#type' => 'textfield',
      '#title' => t('Blur'),
      '#default_value' => $settings['shadow_blur'],
      '#description' => t('The blur applied to the shadow.<br>Property highlighted in example: 10px 10px <b>8px</b> 10px #888888<br>Please enter a value for all the fields to toggle the shadow properties.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['shadow']['shadow_spread'] = array(
      '#type' => 'textfield',
      '#title' => t('Spread'),
      '#default_value' => $settings['shadow_spread'],
      '#description' => t('The spread applied to the shadow.<br>Property highlighted in example: 10px 10px 8px <b>10px</b> #888888<br>Please enter a value for all the fields to toggle the shadow properties.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['shadow']['shadow_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Color'),
      '#default_value' => $settings['shadow_color'],
      '#description' => t('The color applied to the shadow.<br>Property highlighted in example: 10px 10px 8px 10px <b>#888888</b><br>Please enter a value for all the fields to toggle the shadow properties.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Headings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['headings_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Color'),
      '#default_value' => $settings['headings_color'],
      '#description' => t('The CSS color applied to the heading elements.<br>Default: #0282a5.'),
      '#size' => 60,
    );
    $form['style']['headings']['headings_font_family'] = array(
      '#type' => 'textfield',
      '#title' => t('Font family'),
      '#default_value' => $settings['headings_font_family'],
      '#description' => t('The font family applied to the heading elements.<br>Default: Sans Serif.'),
      '#size' => 60,
    );
    $form['style']['headings']['h1'] = array(
      '#type' => 'fieldset',
      '#title' => t('h1'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['h1']['headings_h1_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['headings_h1_font_size'],
      '#description' => t('The font size applied to the heading element.<br>Default: 20px.'),
      '#size' => 60,
    );
    $form['style']['headings']['h1']['headings_h1_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['headings_h1_font_weight'],
      '#description' => t('The font weight applied to the heading element.<br>Default: 600.'),
      '#size' => 60,
    );
    $form['style']['headings']['h1']['headings_h1_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['headings_h1_text_transform'],
      '#description' => t('The transform applied to the text.<br>Default: Unset.'),
    );
    $form['style']['headings']['h1']['headings_h1_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['headings_h1_margin'],
      '#description' => t('The margin applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h1']['headings_h1_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['headings_h1_padding'],
      '#description' => t('The padding applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h1']['headings_h1_letter_spacing'] = array(
      '#type' => 'textfield',
      '#title' => t('Letter spacing'),
      '#default_value' => $settings['headings_h1_letter_spacing'],
      '#description' => t('The letter spacing applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h1']['headings_h1_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['headings_h1_line_height'],
      '#description' => t('The line height applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h1']['headings_h1_important'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enforce styles'),
      '#default_value' => $settings['headings_h1_important'],
      '#description' => t('Add an !important at the end of the styles to make sure they are set.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['style']['headings']['h2'] = array(
      '#type' => 'fieldset',
      '#title' => t('h2'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['h2']['headings_h2_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['headings_h2_font_size'],
      '#description' => t('The font size applied to the heading element.<br>Default: 20px.'),
      '#size' => 60,
    );
    $form['style']['headings']['h2']['headings_h2_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['headings_h2_font_weight'],
      '#description' => t('The font weight applied to the heading element.<br>Default: 600.'),
      '#size' => 60,
    );
    $form['style']['headings']['h2']['headings_h2_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['headings_h2_text_transform'],
      '#description' => t('The transform applied to the text.<br>Default: Unset.'),
    );
    $form['style']['headings']['h2']['headings_h2_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['headings_h2_margin'],
      '#description' => t('The margin applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h2']['headings_h2_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['headings_h2_padding'],
      '#description' => t('The padding applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h2']['headings_h2_letter_spacing'] = array(
      '#type' => 'textfield',
      '#title' => t('Letter spacing'),
      '#default_value' => $settings['headings_h2_letter_spacing'],
      '#description' => t('The letter spacing applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h2']['headings_h2_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['headings_h2_line_height'],
      '#description' => t('The line height applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h2']['headings_h2_important'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enforce styles'),
      '#default_value' => $settings['headings_h2_important'],
      '#description' => t('Add an !important at the end of the styles to make sure they are set.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['style']['headings']['h3'] = array(
      '#type' => 'fieldset',
      '#title' => t('h3'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['h3']['headings_h3_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['headings_h3_font_size'],
      '#description' => t('The font size applied to the heading element.<br>Default: 20px.'),
      '#size' => 60,
    );
    $form['style']['headings']['h3']['headings_h3_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['headings_h3_font_weight'],
      '#description' => t('The font weight applied to the heading element.<br>Default: 600.'),
      '#size' => 60,
    );
    $form['style']['headings']['h3']['headings_h3_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['headings_h3_text_transform'],
      '#description' => t('The transform applied to the text.<br>Default: Unset.'),
    );
    $form['style']['headings']['h3']['headings_h3_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['headings_h3_margin'],
      '#description' => t('The margin applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h3']['headings_h3_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['headings_h3_padding'],
      '#description' => t('The padding applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h3']['headings_h3_letter_spacing'] = array(
      '#type' => 'textfield',
      '#title' => t('Letter spacing'),
      '#default_value' => $settings['headings_h3_letter_spacing'],
      '#description' => t('The letter spacing applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h3']['headings_h3_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['headings_h3_line_height'],
      '#description' => t('The line height applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h3']['headings_h3_important'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enforce styles'),
      '#default_value' => $settings['headings_h3_important'],
      '#description' => t('Add an !important at the end of the styles to make sure they are set.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['style']['headings']['h4'] = array(
      '#type' => 'fieldset',
      '#title' => t('h4'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['h4']['headings_h4_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['headings_h4_font_size'],
      '#description' => t('The font size applied to the heading element.<br>Default: 20px.'),
      '#size' => 60,
    );
    $form['style']['headings']['h4']['headings_h4_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['headings_h4_font_weight'],
      '#description' => t('The font weight applied to the heading element.<br>Default: 600.'),
      '#size' => 60,
    );
    $form['style']['headings']['h4']['headings_h4_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['headings_h4_text_transform'],
      '#description' => t('The transform applied to the text.<br>Default: Unset.'),
    );
    $form['style']['headings']['h4']['headings_h4_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['headings_h4_margin'],
      '#description' => t('The margin applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h4']['headings_h4_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['headings_h4_padding'],
      '#description' => t('The padding applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h4']['headings_h4_letter_spacing'] = array(
      '#type' => 'textfield',
      '#title' => t('Letter spacing'),
      '#default_value' => $settings['headings_h4_letter_spacing'],
      '#description' => t('The letter spacing applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h4']['headings_h4_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['headings_h4_line_height'],
      '#description' => t('The line height applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h4']['headings_h4_important'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enforce styles'),
      '#default_value' => $settings['headings_h4_important'],
      '#description' => t('Add an !important at the end of the styles to make sure they are set.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['style']['headings']['h5'] = array(
      '#type' => 'fieldset',
      '#title' => t('h5'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['h5']['headings_h5_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['headings_h5_font_size'],
      '#description' => t('The font size applied to the heading element.<br>Default: 20px.'),
      '#size' => 60,
    );
    $form['style']['headings']['h5']['headings_h5_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['headings_h5_font_weight'],
      '#description' => t('The font weight applied to the heading element.<br>Default: 600.'),
      '#size' => 60,
    );
    $form['style']['headings']['h5']['headings_h5_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['headings_h5_text_transform'],
      '#description' => t('The transform applied to the text.<br>Default: Unset.'),
    );
    $form['style']['headings']['h5']['headings_h5_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['headings_h5_margin'],
      '#description' => t('The margin applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h5']['headings_h5_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['headings_h5_padding'],
      '#description' => t('The padding applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h5']['headings_h5_letter_spacing'] = array(
      '#type' => 'textfield',
      '#title' => t('Letter spacing'),
      '#default_value' => $settings['headings_h5_letter_spacing'],
      '#description' => t('The letter spacing applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h5']['headings_h5_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['headings_h5_line_height'],
      '#description' => t('The line height applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h5']['headings_h5_important'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enforce styles'),
      '#default_value' => $settings['headings_h5_important'],
      '#description' => t('Add an !important at the end of the styles to make sure they are set.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['style']['headings']['h6'] = array(
      '#type' => 'fieldset',
      '#title' => t('h6'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['headings']['h6']['headings_h6_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['headings_h6_font_size'],
      '#description' => t('The font size applied to the heading element.<br>Default: 20px.'),
      '#size' => 60,
    );
    $form['style']['headings']['h6']['headings_h6_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['headings_h6_font_weight'],
      '#description' => t('The font weight applied to the heading element.<br>Default: 600.'),
      '#size' => 60,
    );
    $form['style']['headings']['h6']['headings_h6_text_transform'] = array(
      '#type' => 'select',
      '#title' => t('Text transform'),
      '#options' => array(
        'capitalize' => t('Capitalize'),
        'lowercase' => t('Lowercase'),
        'uppercase' => t('Uppercase'),
        '' => t('Unset'),
      ),
      '#default_value' => $settings['headings_h6_text_transform'],
      '#description' => t('The transform applied to the text.<br>Default: Unset.'),
    );
    $form['style']['headings']['h6']['headings_h6_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['headings_h6_margin'],
      '#description' => t('The margin applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h6']['headings_h6_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['headings_h6_padding'],
      '#description' => t('The padding applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h6']['headings_h6_letter_spacing'] = array(
      '#type' => 'textfield',
      '#title' => t('Letter spacing'),
      '#default_value' => $settings['headings_h6_letter_spacing'],
      '#description' => t('The letter spacing applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h6']['headings_h6_line_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Line height'),
      '#default_value' => $settings['headings_h6_line_height'],
      '#description' => t('The line height applied to the heading element.<br>Default: (empty).'),
      '#size' => 60,
    );
    $form['style']['headings']['h6']['headings_h6_important'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enforce styles'),
      '#default_value' => $settings['headings_h6_important'],
      '#description' => t('Add an !important at the end of the styles to make sure they are set.<br>Default: disabled.'),
      '#size' => 60,
    );
    $form['style']['body'] = array(
      '#type' => 'fieldset',
      '#title' => t('Body'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['style']['body']['body_font_color'] = array(
      '#type' => 'textfield',
      '#title' => t('Font color'),
      '#default_value' => $settings['body_font_color'],
      '#description' => t('The font color applied to the content within the body field.<br>Default: #000000.'),
      '#size' => 60,
    );
    $form['style']['body']['body_font_family'] = array(
      '#type' => 'textfield',
      '#title' => t('Font family'),
      '#default_value' => $settings['body_font_family'],
      '#description' => t('The font family applied to the content within the body field.<br>Default: Sans Serif.'),
      '#size' => 60,
    );
    $form['style']['body']['body_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Font size'),
      '#default_value' => $settings['body_font_size'],
      '#description' => t('The font size applied to the content within the body field.<br>Default: 16px.'),
      '#size' => 60,
    );
    $form['style']['body']['body_font_weight'] = array(
      '#type' => 'textfield',
      '#title' => t('Font weight'),
      '#default_value' => $settings['body_font_weight'],
      '#description' => t('The font weight applied to the content within the body field.<br>Default: 300.'),
      '#size' => 60,
    );
    $form['style']['body']['body_height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#default_value' => $settings['body_height'],
      '#description' => t('The actual height applied to the scrollable body of the block.<br>Default: calc(100% - 100px).'),
      '#size' => 60,
    );
    $form['style']['body']['body_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#default_value' => $settings['body_width'],
      '#description' => t('The actual width applied to the scrollable body of the block.<br>Default: 100%.'),
      '#size' => 60,
    );
    $form['style']['body']['body_max_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Max width'),
      '#default_value' => $settings['body_max_width'],
      '#description' => t('The actual max width applied to the scrollable body of the block.<br>Default: 100%.'),
      '#size' => 60,
    );
    $form['style']['body']['body_margin'] = array(
      '#type' => 'textfield',
      '#title' => t('Margin'),
      '#default_value' => $settings['body_margin'],
      '#description' => t('The margin applied to the scrollable body of the block.<br>Default: 0 auto.'),
      '#size' => 60,
    );
    $form['style']['body']['body_padding'] = array(
      '#type' => 'textfield',
      '#title' => t('Padding'),
      '#default_value' => $settings['body_padding'],
      '#description' => t('The padding applied to the scrollable body of the block.<br>Default: 0.'),
      '#size' => 60,
    );
  }
  return $form;
}
